@@ -601,7 +601,11 @@ char *help_scrollback_help[] = {
 		"lines. This size can be set with the ^-m^ command-",
 		"line parameter or the ^m^-key in the main menu.",
 		" ^c^     set colors",
+#ifdef __APPLE__
+		" ^x^     copy contents to clipboard (pbcopy)",
+#else
 		" ^x^     copy contents to X clipboard (xclip)",
+#endif
 		" ^f^/^/^   search for a string in the buffer",
 		" ^n^     find the next occurence",
 		" ^Y^     toggle linewrap. if linewrap is disabled,",
@@ -612,6 +616,7 @@ char *help_scrollback_help[] = {
 		" ^t^     show a list of window-nrs and what they",
 		"       contain. can also display statistics.",
 		" ^s^     save the buffer to a file",
+		" ^F9^/^ctrl+w^ switch to full screen mode (and back)",
 		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
@@ -1436,6 +1441,7 @@ void usage(void)
 	help_header("line prefixes");
 	format_help(NULL, "--basename", "only display the filename (and not the path) in the statusline");
 	format_help(NULL, "--label x", "put in front of each line");
+	format_help(NULL, "--all-label x", "put in front of each line for all following windows");
 	format_help("-S prepend", NULL, "show subwindow number in merged output");
 	fprintf(stderr, "\n");
 
